@@ -18,6 +18,8 @@ class DataFeedEventService:
         self.im_listeners = []
         self.connection_listeners = []
         self.elements_listeners = []
+        self.suppression_listeners = []
+        self.wall_post_listeners = []
         self.registered_triggers = []
         self.stop = False
         self.datafeed_client = self.bot_client.get_datafeed_client()
@@ -48,6 +50,21 @@ class DataFeedEventService:
     def add_elements_listener(self, elements_listener):
         self.elements_listeners.append(elements_listener)
 
+    def remove_elements_listener(self, elements_listener):
+        self.elements_listeners.remove(elements_listener)
+
+    def add_wall_post_listener(self, wall_post_listener):
+        self.wall_post_listeners.append(wall_post_listener)
+
+    def remove_wall_post_listener(self, wall_post_listener):
+        self.wall_post_listeners.remove(self, wall_post_listener)
+
+    def add_suppression_listener(self, suppression_listener):
+        self.suppression_listeners.append(suppression_listener)
+    
+    def remove_suppression_listener(self, suppression_listener):
+        self.suppression_listeners.remove(suppression_listener)
+
     def activate_datafeed(self):
         if self.stop:
             self.stop = False
@@ -131,6 +148,8 @@ class DataFeedEventService:
             self.room_deactivated_handler(payload)
         elif event_type == 'ROOMREACTIVATED':
             self.room_reactivated_handler(payload)
+        elif event_type == 'ROOMUPDATED':
+            self.room_updated_handler(payload)
         elif event_type == 'USERJOINEDROOM':
             self.user_joined_room_handler(payload)
         elif event_type == 'USERLEFTROOM':
@@ -145,6 +164,10 @@ class DataFeedEventService:
             self.connection_requested_handler(payload)
         elif event_type == 'SYMPHONYELEMENTSACTION':
             self.elements_action_handler(payload)
+        elif event_type == 'MESSAGESUPPRESSED':
+            self.suppressed_message_handler(payload)
+        elif event_type == 'SHAREDPOST':
+            self.shared_post_handler(payload)
         else:
             logging.debug('no event detected')
             return
@@ -157,6 +180,9 @@ class DataFeedEventService:
         if str(stream_type) == 'ROOM':
             for listener in self.room_listeners:
                 listener.on_room_msg(message_sent_data)
+        elif str(stream_type) == 'POST':
+            for listener in self.wall_post_listeners:
+                listener.on_wall_post_msg(message_sent_data)
         else:
             for listener in self.im_listeners:
                 listener.on_im_message(message_sent_data)
@@ -231,3 +257,15 @@ class DataFeedEventService:
         logging.debug('elements_action_handler')
         for listener in self.elements_listeners:
             listener.on_elements_action(payload)
+
+    def shared_post_handler(self, payload):
+        logging.debug('shared_post_handler')
+        shared_post = payload['payload']['sharedPost']
+        for listener in self.wall_post_listeners:
+            listener.on_shared_post(shared_post)
+    
+    def suppressed_message_handler(self, payload):
+        logging.debug('suppressed_message_handler')
+        message_suppressed = payload['payload']['messageSuppressed']
+        for listener in self.suppression_listeners:
+            listener.on_message_suppression(message_suppressed)
\ No newline at end of file
